summaryrefslogtreecommitdiffstats
path: root/chrome/service/service_utility_process_host.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/service/service_utility_process_host.cc')
-rw-r--r--chrome/service/service_utility_process_host.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/service/service_utility_process_host.cc b/chrome/service/service_utility_process_host.cc
index f0bc621..66cc028 100644
--- a/chrome/service/service_utility_process_host.cc
+++ b/chrome/service/service_utility_process_host.cc
@@ -7,11 +7,11 @@
#include "base/bind.h"
#include "base/command_line.h"
#include "base/file_util.h"
+#include "base/files/scoped_temp_dir.h"
#include "base/logging.h"
#include "base/message_loop.h"
#include "base/message_loop_proxy.h"
#include "base/process_util.h"
-#include "base/scoped_temp_dir.h"
#include "base/utf_string_conversions.h"
#include "chrome/common/chrome_switches.h"
#include "chrome/common/chrome_utility_messages.h"
@@ -56,7 +56,7 @@ bool ServiceUtilityProcessHost::StartRenderPDFPagesToMetafile(
NOTIMPLEMENTED();
return false;
#else // !defined(OS_WIN)
- scratch_metafile_dir_.reset(new ScopedTempDir);
+ scratch_metafile_dir_.reset(new base::ScopedTempDir);
if (!scratch_metafile_dir_->CreateUniqueTempDir())
return false;
if (!file_util::CreateTemporaryFileInDir(scratch_metafile_dir_->path(),
@@ -230,12 +230,12 @@ void ServiceUtilityProcessHost::Client::MetafileAvailable(
double scale_factor) {
// The metafile was created in a temp folder which needs to get deleted after
// we have processed it.
- ScopedTempDir scratch_metafile_dir;
+ base::ScopedTempDir scratch_metafile_dir;
if (!scratch_metafile_dir.Set(metafile_path.DirName()))
LOG(WARNING) << "Unable to set scratch metafile directory";
#if defined(OS_WIN)
// It's important that metafile is declared after scratch_metafile_dir so
// that the metafile destructor closes the file before the ScopedTempDir
// destructor tries to remove the directory.
printing::Emf metafile;
if (!metafile.InitFromFile(metafile_path)) {
@@ -230,12 +230,12 @@ void ServiceUtilityProcessHost::Client::MetafileAvailable(
#if defined(OS_WIN)
// It's important that metafile is declared after scratch_metafile_dir so
- // that the metafile destructor closes the file before the ScopedTempDir
+ // that the metafile destructor closes the file before the base::ScopedTempDir
// destructor tries to remove the directory.
printing::Emf metafile;